# -*- coding: utf-8 -*-
from odoo.upgrade import util

def prod_db_only(cr, _version):
    # Adapt cron code
    # the field `scheduled_date` is now a real timestamp column
    cr.execute(
        """
        UPDATE ir_act_server a
           SET code = replace(a.code, 'OR m.scheduled_date = '''' ', '')
          FROM ir_model m
         WHERE m.id = a.model_id
           -- AND a.usage = 'ir_cron'
           AND m.model = 'mail.mail'
           AND a.code LIKE '%OR m.scheduled_date = '''' %'
        """
    )


def migrate(cr, version):
    for id in (
        'custom_plan_tag',
        'odoo_enterprise_tag',
        'odoo_online_tag',
        'odoo_partnership_tag',
        'odoo_v11_tag',
        'self_subscription_tag',
        'sold_subscription_tag',
        'standard_plan_tag',
    ):
        util.rename_xmlid(cr, f"openerp_enterprise.{id}", f"openerp_enterprise.mig16_{id}")
    util.remove_field(cr, 'ir.module.module', 'product_id')
    util.remove_view(cr, 'openerp_enterprise.view_module_form_openerp_enterprise')
    util.remove_view(cr, 'openerp_enterprise.view_module_fitler_openerp_enterprise')
    util.remove_view(cr, 'openerp_enterprise.view_partner_bring_back_go_to_website')
    util.remove_view(cr, 'openerp_enterprise.res_users_view_form_profile_voip')
    util.remove_view(cr, view_id=16616)
    util.remove_view(cr, view_id=16617)
    util.remove_view(cr, view_id=16341)

    util.dispatch_by_dbuuid(cr, version, {"8851207e-1ff9-11e0-a147-001cc0f2115e": prod_db_only})

    cr.execute("""create index "crm_lead_mobile_partial_tgm_idx3" ON crm_lead(regexp_replace((mobile)::text, '[\s\\\\./\(\)\-]', '', 'g')) where mobile is not null""")
    cr.execute("""create index "crm_lead_phone_partial_tgm_idx3" ON crm_lead(regexp_replace((phone)::text, '[\s\\\\./\(\)\-]', '', 'g')) where phone is not null""")
    cr.execute("""create index on crm_lead using gist (unaccent(email_normalized::text) gist_trgm_ops);""")

    # pad questions models and views removal
    util.remove_model(cr, "hr.recruitment.question")
    util.remove_model(cr, "hr.recruitment.question.category")

    util.remove_field(cr, "hr.applicant", "has_interview_pad")
    util.remove_field(cr, "hr.applicant", "pad_success")

    util.remove_view(cr, "openerp_enterprise.hr_applicant_pad_question")
    util.remove_view(cr, "openerp_enterprise.application_review_list_applicant")
    util.remove_view(cr, "openerp_enterprise.application_review_list")
    util.remove_view(cr, "openerp_enterprise.application_review_applicant")
    util.remove_view(cr, "openerp_enterprise.pad_review_portal_layout")
    util.remove_view(cr, "openerp_enterprise.pad_review_portal_my_home")

    util.ensure_xmlid_match_record(
        cr, "openerp_enterprise.hr_recruitment_stage_qualified",
        "hr.recruitment.stage", {'id': 14}
    )
